==> qmmp-0.8.6.tar.bz2: qmmp-0.8.6/src/plugins/Visual/projectm/translations/projectm_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>Na&amp;me des Titels anzeigen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>N&amp;ame der Voreinstellung anzeigen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Nächste Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>Vor&amp;herige Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Zufällige Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>V&amp;oreinstellung sperren</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation>V</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Über ProjectM-Visualisierungsmodul</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM-Visualisierungsmodul</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Dieses Modul fügt Unterstützung für ProjectM-Visualisierungen hinzu</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Basiert auf der libprojectM-Qt-Bibliothek</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Visual/projectm/translations/projectm_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="161"/>
        <source>&amp;Show Song Title</source>
        <translation>Liedna&amp;me anzeigen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="161"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="162"/>
        <source>&amp;Show Preset Name</source>
        <translation>N&amp;ame der Voreinstellung anzeigen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="162"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="163"/>
        <source>&amp;Show Menu</source>
        <translation>Menü an&amp;zeigen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="163"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Nächste Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Previous Preset</source>
        <translation>Vor&amp;herige Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>P</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Zufällige Voreinstellung</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>R</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="168"/>
        <source>&amp;Lock Preset</source>
        <translation>V&amp;oreinstellung sperren</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="168"/>
        <source>L</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>F</source>
        <translation>V</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="30"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Über ProjectM-Visualisierungsmodul</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM-Visualisierungsmodul</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Dieses Modul fügt ProjectM-Visualisierungen hinzu</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="54"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Basiert auf der libprojectM-Qt-Bibliothek</translation>
    </message>
</context>
</TS>
